# heatsource_thm.jl
## Analytical solution of  a problem describing a heat source embedded in a fluid-saturated porous medium.

For numerical validation see: https://www.opengeosys.org/docs/benchmarks/thermo-hydro-mechanics/consolidation_pointheatsource/

Original publication: Booker, J. R.; Savvidou, C. (1985), Consolidation around a point heat source. International Journal for Numerical and Analytical Methods in Geomechanics, 1985, 9. Jg., Nr. 2, S. 173-184.

Correction of stress solution: Chaudhry, A. A.; Buchwald, J.; Kolditz, O. and Nagel, T. (2019), Consolidation around a point heatsource (correction & verification). International Journal for Numerical and Analytical Methods in Geomechanics, 2019, https://doi.org/10.1002/nag.2998.
